#
# spec file for package python-rsa
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-rsa
Version:        3.1.4
Release:        8.2
Url:            http://stuvel.eu/rsa
Summary:        Pure-Python RSA Implementation
License:        Apache-2.0
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/r/rsa/rsa-%{version}.tar.gz
Patch0:         cve_2016-1494.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-pyasn1
BuildRequires:  python-setuptools
BuildRequires:  python-unittest2
Requires(pre):  coreutils
Requires:       python-pyasn1
Requires(pre):  coreutils
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Python-RSA is a pure-Python RSA implementation. It supports encryption and
decryption, signing and verifying signatures, and key generation according to
PKCS#1 version 1.5.

%prep
%setup -q -n rsa-%{version}
sed -i "s/pyrsa-priv2pub/pyrsa-priv2pub-%{py_ver}/" setup.py
sed -i "s/pyrsa-keygen/pyrsa-keygen-%{py_ver}/" setup.py
sed -i "s/pyrsa-encrypt =/pyrsa-encrypt-%{py_ver} =/" setup.py
sed -i "s/pyrsa-decrypt =/pyrsa-decrypt-%{py_ver} =/" setup.py
sed -i "s/pyrsa-sign/pyrsa-sign-%{py_ver}/" setup.py
sed -i "s/pyrsa-verify/pyrsa-verify-%{py_ver}/" setup.py
sed -i "s/pyrsa-encrypt-bigfile =/pyrsa-encrypt-bigfile-%{py_ver} =/" setup.py
sed -i "s/pyrsa-decrypt-bigfile =/pyrsa-decrypt-bigfile-%{py_ver} =/" setup.py
%patch0 -p1

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# for update-alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for f in pyrsa-priv2pub pyrsa-keygen pyrsa-encrypt pyrsa-decrypt pyrsa-sign \
         pyrsa-verify pyrsa-encrypt-bigfile pyrsa-decrypt-bigfile; do
    touch %{buildroot}%{_sysconfdir}/alternatives/$f
    ln -sf %{_sysconfdir}/alternatives/$f %{buildroot}%{_bindir}/$f
done

%check
python run_tests.py

%pre
# Since binaries became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/pyrsa-priv2pub ] || rm -f %{_bindir}/pyrsa-priv2pub
[ -h %{_bindir}/pyrsa-keygen ] || rm -f %{_bindir}/pyrsa-keygen
[ -h %{_bindir}/pyrsa-encrypt ] || rm -f %{_bindir}/pyrsa-encrypt
[ -h %{_bindir}/pyrsa-decrypt ] || rm -f %{_bindir}/pyrsa-decrypt
[ -h %{_bindir}/pyrsa-sign ] || rm -f %{_bindir}/pyrsa-sign
[ -h %{_bindir}/pyrsa-verify ] || rm -f %{_bindir}/pyrsa-verify
[ -h %{_bindir}/pyrsa-encrypt-bigfile ] || rm -f %{_bindir}/pyrsa-encrypt-bigfile
[ -h %{_bindir}/pyrsa-decrypt-bigfile ] || rm -f %{_bindir}/pyrsa-decrypt-bigfile

%post
update-alternatives \
    --install %{_bindir}/pyrsa-priv2pub pyrsa-priv2pub %{_bindir}/pyrsa-priv2pub-%{py_ver} 30 \
    --slave %{_bindir}/pyrsa-keygen pyrsa-keygen %{_bindir}/pyrsa-keygen-%{py_ver} \
    --slave %{_bindir}/pyrsa-encrypt pyrsa-encrypt %{_bindir}/pyrsa-encrypt-%{py_ver} \
    --slave %{_bindir}/pyrsa-decrypt pyrsa-decrypt %{_bindir}/pyrsa-decrypt-%{py_ver} \
    --slave %{_bindir}/pyrsa-sign pyrsa-sign %{_bindir}/pyrsa-sign-%{py_ver} \
    --slave %{_bindir}/pyrsa-verify pyrsa-verify %{_bindir}/pyrsa-verify-%{py_ver} \
    --slave %{_bindir}/pyrsa-encrypt-bigfile pyrsa-encrypt-bigfile %{_bindir}/pyrsa-encrypt-bigfile-%{py_ver} \
    --slave %{_bindir}/pyrsa-decrypt-bigfile pyrsa-decrypt-bigfile %{_bindir}/pyrsa-decrypt-bigfile-%{py_ver} \

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove pyrsa-priv2pub %{_bindir}/pyrsa-priv2pub-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%ghost %{_sysconfdir}/alternatives/pyrsa-priv2pub
%ghost %{_sysconfdir}/alternatives/pyrsa-keygen
%ghost %{_sysconfdir}/alternatives/pyrsa-encrypt
%ghost %{_sysconfdir}/alternatives/pyrsa-decrypt
%ghost %{_sysconfdir}/alternatives/pyrsa-sign
%ghost %{_sysconfdir}/alternatives/pyrsa-verify
%ghost %{_sysconfdir}/alternatives/pyrsa-encrypt-bigfile
%ghost %{_sysconfdir}/alternatives/pyrsa-decrypt-bigfile
%{_bindir}/pyrsa-priv2pub
%{_bindir}/pyrsa-priv2pub-%{py_ver}
%{_bindir}/pyrsa-keygen
%{_bindir}/pyrsa-keygen-%{py_ver}
%{_bindir}/pyrsa-encrypt
%{_bindir}/pyrsa-encrypt-%{py_ver}
%{_bindir}/pyrsa-decrypt
%{_bindir}/pyrsa-decrypt-%{py_ver}
%{_bindir}/pyrsa-sign
%{_bindir}/pyrsa-sign-%{py_ver}
%{_bindir}/pyrsa-verify
%{_bindir}/pyrsa-verify-%{py_ver}
%{_bindir}/pyrsa-encrypt-bigfile
%{_bindir}/pyrsa-encrypt-bigfile-%{py_ver}
%{_bindir}/pyrsa-decrypt-bigfile
%{_bindir}/pyrsa-decrypt-bigfile-%{py_ver}
%{python_sitelib}/*

%changelog
* Tue Jan  5 2016 rjschwei@suse.com
- Fix CVE 2016-1494 (bsc#960680)
  - Add patch cve_2016-1494.diff
* Tue Dec  1 2015 rjschwei@suse.com
- Include version 3.1.4 in SLE 12 (FATE#319904, bsc#954690)
* Fri Nov 20 2015 p.drouand@gmail.com
- Fix coreutils requirement
* Wed Sep 23 2015 rjschwei@suse.com
- require coreutils (bsc#935595)
  + %%pre section uses rm which is part of coreutils package
* Tue May 12 2015 benoit.monin@gmx.fr
- update to version 3.1.4:
  * no changelog available
- add test dependency python-unittest2
- fix update-alternatives
- run the tests with run_tests.py
- add README.rst to the package documentation
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Fri Oct 11 2013 p.drouand@gmail.com
- Update to version 3.1.2
  + No changelog available
- Replace python-distribute with python-setuptools BuildRequires
- Remove rsa-use-system-setuptools.patch; merged upstream
- Implement update-alternatives
* Mon Aug 12 2013 speilicke@suse.com
- Add rsa-use-system-setuptools.patch
* Fri Nov 23 2012 speilicke@suse.com
- Update to version 3.1.1:
  + Upstream provides no changelog
* Fri May 18 2012 jfunk@funktronics.ca
- Initial release
